@@ -8,7 +8,9 @@ parser = argparse.ArgumentParser(description="Make some samples (names of people
 parser.add_argument(
     "--number", type=int, action="store", help="the number of samples you want to make"
 )
-parser.add_argument("--filepath", type=str, default="samples_file.npy", help="output file")
+parser.add_argument(
+    "--filepath", type=str, default="samples_file.npy", help="output file"
+)
 args = parser.parse_args()
 
 # sample making
