@@ -43,7 +43,7 @@ def single_task_times():
                     match = matches.group(0)
                     match = float(match.strip("s:"))
                     task_durations.append(match)
-        except:
+        except BaseException:
             continue
 
     print(str(task_durations))
@@ -62,7 +62,7 @@ def merlin_run_time():
         total += result
     try:
         print(f"c{args.c}_s{args.s} merlin run : " + str(result))
-    except:
+    except BaseException:
         result = None
         print(
             f"c{args.c}_s{args.s} merlin run : ERROR -- result={result}, args.errfile={args.errfile}"
@@ -82,7 +82,7 @@ def start_verify_time():
             element = datetime.datetime.strptime(match, "%Y-%m-%d %H:%M:%S,%f")
             timestamp = datetime.datetime.timestamp(element)
             all_timestamps.append(timestamp)
-        except:
+        except BaseException:
             continue
         try:
             print(f"c{args.c}_s{args.s} start verify : " + str(all_timestamps[0]))
@@ -103,7 +103,7 @@ def start_run_workers_time():
             element = datetime.datetime.strptime(match, "%Y-%m-%d %H:%M:%S,%f")
             timestamp = datetime.datetime.timestamp(element)
             all_timestamps.append(timestamp)
-        except:
+        except BaseException:
             continue
     earliest = min(all_timestamps)
     print(f"c{args.c}_s{args.s} start run-workers : " + str(earliest))
@@ -122,7 +122,7 @@ def start_sample1_time():
             element = datetime.datetime.strptime(match, "%Y-%m-%d %H:%M:%S,%f")
             timestamp = datetime.datetime.timestamp(element)
             all_timestamps.append(timestamp)
-        except:
+        except BaseException:
             continue
     earliest = min(all_timestamps)
     print(f"c{args.c}_s{args.s} start samp1 : " + str(earliest))
